@@ -1,3 +1,12 @@
+"""
+The aiopyramid.traversal module is deprecated, use aiopyramid.helpers.synchronize instead.
+See http://aiopyramid.readthedocs.org/en/latest/features.html#traversal.
+"""  # noqa
+
+import warnings
+warnings.warn(__doc__, DeprecationWarning)
+
+
 import asyncio
 
 from pyramid.traversal import (
@@ -27,6 +36,11 @@ def traverse(
     root,
     subpath,
 ):
+    """
+    A version of :func:`pyramid.traversal.traverse` that expects `__getitem__`
+    to be a :term:`coroutine`.
+    """
+
     for segment in vpath_tuple:
         if segment[:2] == view_selector:
             return {
